@@ -179,15 +179,18 @@ msg = {
     "2802" : "The problem does not exist",
     "2803" : "No permission to delete this label",
 
-    "2900" : "The final output file name is wrong",
-    "2901" : "Cmd format error",
-    "2902" : "Duplicate cmd key",
-    "2903" : "Operational resources are locked",
-    "2904" : "File key does not match cmd key",
-    "2905" : "Worker node type does not exist",
-    "2906" : "Oss file reference error",
-    "2907" : "Worker type not selected",
-    "2908" : "Wrong Worker type selection",
-    "2909" : "The number of references for this resource is zero",
-    "2910" : "Text conversion error"
+    "2900": "The final output file name is wrong",
+    "2901": "Cmd format error",
+    "2902": "Duplicate cmd key",
+    "2903": "Operational resources are locked",
+    "2904": "File key does not match cmd key",
+    "2905": "Worker node type does not exist",
+    "2906": "Oss file reference error",
+    "2907": "Worker type not selected",
+    "2908": "Wrong Worker type selection",
+    "2909": "The number of references for this resource is zero",
+    "2910": "Text conversion error",
+    "2911": "Input file list error",
+    "2912": "Output file list error",
+    "2913": "CMD does not match the parameter"
   }
\ No newline at end of file
