@@ -1,6 +1,6 @@
 import os
 
-version = '0.0.20'
+version = '0.0.21'
 
 # 开发
 login_base_url_develop = 'http://develop.flowhub.com.cn:8080'
@@ -15,7 +15,7 @@ docker_registry_stage = 'stage.flowhub.com.cn:5000'
 # 生产
 login_base_url_master = 'https://www.flowhub.com.cn/backend'
 cloud_base_url_master = 'https://www.flowhub.com.cn/cloud'
-docker_registry_master = 'tool.flowhub.com.cn:5000'
+docker_registry_master = 'www.flowhub.com.cn:5000'
 
 cli_dir = '.cli'
 USER_BASE_PATH = os.path.expanduser('~')
